
Core functions
--------------

.. autosummary::

    bioconvert.core.base
    bioconvert.core.benchmark
    bioconvert.core.converter
    bioconvert.core.decorators
    bioconvert.core.downloader
    bioconvert.core.extensions
    bioconvert.core.graph
    bioconvert.core.registry
    bioconvert.core.shell
    bioconvert.core.utils


Base
~~~~

.. automodule:: bioconvert.core.base
    :members:
    :synopsis:

Benchmark
~~~~~~~~~

.. automodule:: bioconvert.core.benchmark
    :members:
    :synopsis:

Converter
~~~~~~~~~

.. automodule:: bioconvert.core.converter
    :members:
    :synopsis:

Decorators
~~~~~~~~~~

.. automodule:: bioconvert.core.decorators
    :members:
    :synopsis:

Downloader
~~~~~~~~~~

.. automodule:: bioconvert.core.downloader
    :members:
    :synopsis:

Extensions
~~~~~~~~~~

.. automodule:: bioconvert.core.extensions
    :members:
    :synopsis:

Graph
~~~~~

.. automodule:: bioconvert.core.graph
    :members:
    :synopsis:

Registry
~~~~~~~~

.. automodule:: bioconvert.core.registry
    :members:
    :synopsis:

Utils
~~~~~

.. automodule:: bioconvert.core.utils
    :members:
    :synopsis:


